@@ -1,8 +1,7 @@
 get_eigenprods <- function(cov_matrix, X, y, ones) {
-
   eig <- eigen(Matrix::forceSymmetric(cov_matrix))
-  SigInv_p1 <- t(t(eig$vectors) * 1/eig$values)
-  SqrtSigInv_p1 <- t(t(eig$vectors) * 1/sqrt(eig$values))
+  SigInv_p1 <- t(t(eig$vectors) * 1 / eig$values)
+  SqrtSigInv_p1 <- t(t(eig$vectors) * 1 / sqrt(eig$values))
   p2_X <- t(eig$vectors) %*% X
   p2_y <- t(eig$vectors) %*% y
   p2_ones <- t(eig$vectors) %*% ones
@@ -12,8 +11,10 @@ get_eigenprods <- function(cov_matrix, X, y, ones) {
   SqrtSigInv_X <- SqrtSigInv_p1 %*% p2_X
   SqrtSigInv_y <- SqrtSigInv_p1 %*% p2_y
   SqrtSigInv_ones <- SqrtSigInv_p1 %*% p2_ones
-  list(SigInv_X = SigInv_X, SigInv_y = SigInv_y, SigInv_ones = SigInv_ones,
-       SqrtSigInv_X = SqrtSigInv_X, SqrtSigInv_y = SqrtSigInv_y, SqrtSigInv_ones = SqrtSigInv_ones)
+  list(
+    SigInv_X = SigInv_X, SigInv_y = SigInv_y, SigInv_ones = SigInv_ones,
+    SqrtSigInv_X = SqrtSigInv_X, SqrtSigInv_y = SqrtSigInv_y, SqrtSigInv_ones = SqrtSigInv_ones
+  )
 }
 
 get_eigenprods_parallel <- function(cluster_list) {
