@@ -69,10 +69,25 @@
 #'   If \code{local} is \code{TRUE}, defaults for \code{local} are chosen such
 #'   that \code{local} is transformed into
 #'   \code{list(size = 100, method = "covariance", parallel = FALSE)}.
+#'
+#'   If \code{block} is \code{TRUE}, \code{local} accepts \code{method} and \code{size},
+#'   and \code{method} takes values of \code{"all"}, \code{"covariance"},
+#'   and \code{"distance"}, similar as when \code{block} is \code{FALSE}.
+#'   The default \code{method} is \code{"distance"} with size \code{1000}. This default \code{size} is
+#'   much larger than when \code{block} is \code{FALSE}. This is because when \code{block} is \code{TRUE},
+#'   covariances and explanatory variables are averaged before prediction, which greatly
+#'   reduces computational burden, only requiring the Cholesky decomposition
+#'   of one observed covariance matrix. Because the computational burden is reduced dramatically when \code{block} is \code{TRUE},
+#'   parallel processing is not needed and hence, \code{parallel} and \code{ncores} are ignored if specified in \code{local}.
 #' @param terms If \code{type} is \code{"terms"}, the type of terms to be returned,
 #'   specified via either numeric position or name. The default is all terms are included.
 #' @param na.action Missing (\code{NA}) values in \code{newdata} will return an error and should
 #'   be removed before proceeding.
+#' @param block A logical indicating whether a block prediction over the entire region
+#'   in \code{newdata} should be returned. When \code{block} is \code{TRUE},
+#'   \code{newdata} should be a dense grid of prediction locations that span
+#'   the entire region. The default is \code{FALSE}, which
+#'   returns point predictions for each location on \code{newdata}.
 #' @param ... Other arguments. Only used for models fit using \code{splmRF()}
 #'   or \code{spautorRF()} where \code{...} indicates other
 #'   arguments to \code{ranger::predict.ranger()}.
@@ -122,7 +137,8 @@
 #' predict(spmod, sulfate_preds, interval = "prediction")
 #' augment(spmod, newdata = sulfate_preds, interval = "prediction")
 predict.splm <- function(object, newdata, se.fit = FALSE, scale = NULL, df = Inf, interval = c("none", "confidence", "prediction"),
-                         level = 0.95, type = c("response", "terms"), local, terms = NULL, na.action = na.fail, ...) {
+                         level = 0.95, type = c("response", "terms"), block = FALSE, local, terms = NULL, na.action = na.fail, ...) {
+
 
   # match interval argument so the three display
   interval <- match.arg(interval)
@@ -133,6 +149,11 @@ predict.splm <- function(object, newdata, se.fit = FALSE, scale = NULL, df = Inf
     local <- NULL
   }
 
+  if (block) {
+    object <- predict_block_splm(object, newdata, se.fit, scale, df, interval, level, type, local, terms, na.action, ...)
+    return(object)
+  }
+
   # check scale is numeric (if specified)
   if (!is.null(scale) && !is.numeric(scale)) {
     stop("scale must be numeric.", call. = FALSE)
